@@ -79,17 +79,28 @@ sub _build_json_decoder {
 sub run {
     my $self = shift;
 
-    my $config = $self->load_config;
-    my $class  = $self->setup_class($config);
+    try {
+        my $config = $self->load_config;
+        my $class  = $self->setup_class($config);
 
-    $class->name->new_with_options( {
-            home   => $self->home,
-            config => $config,
-            (   $self->has_project
-                ? ( _current_project => $self->project )
-                : ()
-            ),
-        } )->run;
+        $class->name->new_with_options( {
+                home   => $self->home,
+                config => $config,
+                (   $self->has_project
+                    ? ( _current_project => $self->project )
+                    : ()
+                ),
+            } )->run;
+    }
+    catch {
+        my $e = $_;
+        if ( blessed $e && $e->can('message') ) {
+            warn $e->message, "\n";
+        }
+        else {
+            warn "$e\n";
+        }
+    }
 }
 
 sub setup_class {
@@ -125,7 +136,7 @@ sub setup_class {
     if (   $load_attribs_for_command
         && $class->has_method($load_attribs_for_command) )
     {
-        $class->name->$load_attribs_for_command($class);
+        $class->name->$load_attribs_for_command($class, $config);
     }
     $class->make_immutable();
     return $class;
@@ -247,7 +258,7 @@ App::TimeTracker::Proto - App::TimeTracker Proto Class
 
 =head1 VERSION
 
-version 2.022
+version 2.023
 
 =head1 DESCRIPTION
 
